@@ -24,8 +24,9 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
  */
 
-#include <config.h>
+#include "config.h"
 #include "gtkalignment.h"
+#include "gtkprivate.h"
 #include "gtkintl.h"
 #include "gtkalias.h"
 
@@ -40,9 +41,7 @@ enum {
   PROP_TOP_PADDING,
   PROP_BOTTOM_PADDING,
   PROP_LEFT_PADDING,
-  PROP_RIGHT_PADDING,
-  
-  PROP_LAST
+  PROP_RIGHT_PADDING
 };
 
 #define GTK_ALIGNMENT_GET_PRIVATE(o)  (G_TYPE_INSTANCE_GET_PRIVATE ((o), GTK_TYPE_ALIGNMENT, GtkAlignmentPrivate))
@@ -55,8 +54,6 @@ struct _GtkAlignmentPrivate
   guint padding_right;
 };
 
-static void gtk_alignment_class_init    (GtkAlignmentClass *klass);
-static void gtk_alignment_init          (GtkAlignment      *alignment);
 static void gtk_alignment_size_request  (GtkWidget         *widget,
 					 GtkRequisition    *requisition);
 static void gtk_alignment_size_allocate (GtkWidget         *widget,
@@ -70,32 +67,7 @@ static void gtk_alignment_get_property (GObject         *object,
                                         GValue          *value,
                                         GParamSpec      *pspec);
 
-GType
-gtk_alignment_get_type (void)
-{
-  static GType alignment_type = 0;
-
-  if (!alignment_type)
-    {
-      static const GTypeInfo alignment_info =
-      {
-	sizeof (GtkAlignmentClass),
-	NULL,		/* base_init */
-	NULL,		/* base_finalize */
-	(GClassInitFunc) gtk_alignment_class_init,
-	NULL,		/* class_finalize */
-	NULL,		/* class_data */
-	sizeof (GtkAlignment),
-	0,		/* n_preallocs */
-	(GInstanceInitFunc) gtk_alignment_init,
-      };
-
-      alignment_type = g_type_register_static (GTK_TYPE_BIN, "GtkAlignment",
-					       &alignment_info, 0);
-    }
-
-  return alignment_type;
-}
+G_DEFINE_TYPE (GtkAlignment, gtk_alignment, GTK_TYPE_BIN)
 
 static void
 gtk_alignment_class_init (GtkAlignmentClass *class)
@@ -120,7 +92,7 @@ gtk_alignment_class_init (GtkAlignmentClass *class)
                                                       0.0,
                                                       1.0,
                                                       0.5,
-                                                      G_PARAM_READABLE | G_PARAM_WRITABLE));
+                                                      GTK_PARAM_READWRITE));
    
   g_object_class_install_property (gobject_class,
                                    PROP_YALIGN,
@@ -130,7 +102,7 @@ gtk_alignment_class_init (GtkAlignmentClass *class)
                                                       0.0,
                                                       1.0,
 						      0.5,
-                                                      G_PARAM_READABLE | G_PARAM_WRITABLE));
+                                                      GTK_PARAM_READWRITE));
   g_object_class_install_property (gobject_class,
                                    PROP_XSCALE,
                                    g_param_spec_float("xscale",
@@ -139,7 +111,7 @@ gtk_alignment_class_init (GtkAlignmentClass *class)
                                                       0.0,
                                                       1.0,
                                                       1.0,
-                                                      G_PARAM_READABLE | G_PARAM_WRITABLE));
+                                                      GTK_PARAM_READWRITE));
   g_object_class_install_property (gobject_class,
                                    PROP_YSCALE,
                                    g_param_spec_float("yscale",
@@ -148,7 +120,7 @@ gtk_alignment_class_init (GtkAlignmentClass *class)
                                                       0.0,
                                                       1.0,
                                                       1.0,
-                                                      G_PARAM_READABLE | G_PARAM_WRITABLE));
+                                                      GTK_PARAM_READWRITE));
 
 
 /**
@@ -160,16 +132,16 @@ gtk_alignment_class_init (GtkAlignmentClass *class)
  */
   g_object_class_install_property (gobject_class,
                                    PROP_TOP_PADDING,
-                                   g_param_spec_uint("top_padding",
+                                   g_param_spec_uint("top-padding",
                                                       P_("Top Padding"),
                                                       P_("The padding to insert at the top of the widget."),
                                                       0,
                                                       G_MAXINT,
                                                       0,
-                                                      G_PARAM_READABLE | G_PARAM_WRITABLE));
+                                                      GTK_PARAM_READWRITE));
 
 /**
- * GtkAlignment:top-padding:
+ * GtkAlignment:bottom-padding:
  *
  * The padding to insert at the bottom of the widget.
  *
@@ -177,16 +149,16 @@ gtk_alignment_class_init (GtkAlignmentClass *class)
  */
   g_object_class_install_property (gobject_class,
                                    PROP_BOTTOM_PADDING,
-                                   g_param_spec_uint("bottom_padding",
+                                   g_param_spec_uint("bottom-padding",
                                                       P_("Bottom Padding"),
                                                       P_("The padding to insert at the bottom of the widget."),
                                                       0,
                                                       G_MAXINT,
                                                       0,
-                                                      G_PARAM_READABLE | G_PARAM_WRITABLE));
+                                                      GTK_PARAM_READWRITE));
 
 /**
- * GtkAlignment:top-padding:
+ * GtkAlignment:left-padding:
  *
  * The padding to insert at the left of the widget.
  *
@@ -194,16 +166,16 @@ gtk_alignment_class_init (GtkAlignmentClass *class)
  */
   g_object_class_install_property (gobject_class,
                                    PROP_LEFT_PADDING,
-                                   g_param_spec_uint("left_padding",
+                                   g_param_spec_uint("left-padding",
                                                       P_("Left Padding"),
                                                       P_("The padding to insert at the left of the widget."),
                                                       0,
                                                       G_MAXINT,
                                                       0,
-                                                      G_PARAM_READABLE | G_PARAM_WRITABLE));
+                                                      GTK_PARAM_READWRITE));
 
 /**
- * GtkAlignment:top-padding:
+ * GtkAlignment:right-padding:
  *
  * The padding to insert at the right of the widget.
  *
@@ -211,13 +183,13 @@ gtk_alignment_class_init (GtkAlignmentClass *class)
  */
   g_object_class_install_property (gobject_class,
                                    PROP_RIGHT_PADDING,
-                                   g_param_spec_uint("right_padding",
+                                   g_param_spec_uint("right-padding",
                                                       P_("Right Padding"),
                                                       P_("The padding to insert at the right of the widget."),
                                                       0,
                                                       G_MAXINT,
                                                       0,
-                                                      G_PARAM_READABLE | G_PARAM_WRITABLE));
+                                                      GTK_PARAM_READWRITE));
 
   g_type_class_add_private (gobject_class, sizeof (GtkAlignmentPrivate));  
 }
@@ -440,11 +412,9 @@ static void
 gtk_alignment_size_request (GtkWidget      *widget,
 			    GtkRequisition *requisition)
 {
-  GtkAlignment *alignment;
   GtkBin *bin;
   GtkAlignmentPrivate *priv;
 
-  alignment = GTK_ALIGNMENT (widget);
   bin = GTK_BIN (widget);
   priv = GTK_ALIGNMENT_GET_PRIVATE (widget);
 
@@ -478,7 +448,6 @@ gtk_alignment_size_allocate (GtkWidget     *widget,
   gint border_width;
   gint padding_horizontal, padding_vertical;
   GtkAlignmentPrivate *priv;
-  gfloat xalign;
 
   padding_horizontal = 0;
   padding_vertical = 0;
@@ -514,11 +483,11 @@ gtk_alignment_size_allocate (GtkWidget     *widget,
       else
 	child_allocation.height = height;
 
-      xalign = alignment->xalign;
       if (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL)
-	xalign = 1.0 - xalign;
+	child_allocation.x = (1.0 - alignment->xalign) * (width - child_allocation.width) + allocation->x + border_width + priv->padding_right;
+      else 
+	child_allocation.x = alignment->xalign * (width - child_allocation.width) + allocation->x + border_width + priv->padding_left;
 
-      child_allocation.x = xalign * (width - child_allocation.width) + allocation->x + border_width + priv->padding_left;
       child_allocation.y = alignment->yalign * (height - child_allocation.height) + allocation->y + border_width + priv->padding_top;
 
       gtk_widget_size_allocate (bin->child, &child_allocation);
