@@ -18,7 +18,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 #include <string.h>
 
 #include "gtkfilechooserprivate.h"
@@ -694,10 +694,10 @@ _gtk_file_system_model_new (GtkFileSystem     *file_system,
       g_object_unref (model);
       g_object_unref (model);
 
-      g_set_error (error,
-		   GTK_FILE_CHOOSER_ERROR,
-		   GTK_FILE_CHOOSER_ERROR_NONEXISTENT,
-		   _("Could not obtain root folder"));
+      g_set_error_literal (error,
+                           GTK_FILE_CHOOSER_ERROR,
+                           GTK_FILE_CHOOSER_ERROR_NONEXISTENT,
+                           _("Could not obtain root folder"));
 
       return NULL;
     }
@@ -994,7 +994,7 @@ ref_path_cb (GCancellable *cancellable,
 
   if (folder)
     info->cleanups = g_slist_prepend (info->cleanups, folder);
-  else if (g_slist_length (info->files) == 1
+  else if ((info->files != NULL && info->files->next == NULL) /* g_slist_length == 1 */
            && g_file_equal (info->node->file, info->files->data))
     {
       /* Done, now call the function */
@@ -1022,10 +1022,10 @@ ref_path_cb (GCancellable *cancellable,
       goto out;
     }
 
-  g_object_unref (info->files);
+  g_object_unref (info->files->data);
   info->files = g_slist_remove (info->files, info->files->data);
 
-  if (g_slist_length (info->files) < 1)
+  if (info->files == NULL)
     {
       /* Done, now call the function */
       if (info->node)
@@ -1070,7 +1070,8 @@ ref_path_cb (GCancellable *cancellable,
 out:
   if (info->node)
     unref_node_and_parents (info->model, info->node);
-  g_object_unref (info->files);
+  g_slist_foreach (info->files, (GFunc)g_object_unref, NULL);
+  g_slist_free (info->files);
   g_slist_foreach (info->cleanups, (GFunc)g_object_unref, NULL);
   g_slist_free (info->cleanups);
   g_object_unref (info->model);
@@ -1133,8 +1134,9 @@ _gtk_file_system_model_path_do (GtkFileSystemModel        *model,
 	  return;
 	}
     }
+  g_object_unref (parent_file);
 
-  if (g_slist_length (files) < 1)
+  if (files == NULL)
     return;
 
   /* Now we have all paths, except the root path */
@@ -1151,7 +1153,7 @@ _gtk_file_system_model_path_do (GtkFileSystemModel        *model,
   g_object_unref (files->data);
   files = g_slist_remove (files, files->data);
 
-  if (g_slist_length (files) < 1)
+  if (files == NULL)
     {
       /* Done, now call the function */
       if (node)
